@@ -29,6 +29,12 @@ try:
 except:
     get_bus_info_from_camera = None
 
+try:
+    import zmq
+    from tensorcom.tenbin import encode_buffer  # type: ignore
+except:
+    warnings.warn("Could not import ZMQ and tensorcom. Cannot send messages between programs.")
+
 
 class SubscriberWindows(object):
     """Windows that subscribe to updates to cameras, videos, and arrays."""
@@ -52,6 +58,9 @@ class SubscriberWindows(object):
         self.input_cams: List[str] = []
         self.exited = False
         self.silent = silent
+        self.ctx = None
+        self.sock_list: List[zmq.Socket] = []
+        self.top_list: List[bytes] = []
 
         if callbacks is None:
             callbacks = []
@@ -225,9 +234,13 @@ class SubscriberWindows(object):
         if not self.silent:
             self.display_frames(self.frames)
 
-    def update(self, arr: np.ndarray = None, id: str = None):
+    def update(self, arr: Union[List[np.ndarray], np.ndarray] = None, id: Union[List[str],str, List[int], int, None] = None):
         """Update window frames once. Optionally add a new input and input id."""
-        if arr is not None and id is not None:
+        if isinstance(arr, list):
+            assert isinstance(id, list)
+            return self._update_multiple(arr, id)
+        elif arr is not None and id is not None:
+            assert not isinstance(id, list)
             global_cv_display_callback(arr, id)
             if id not in self.input_cams:
                 self.add_source(id)
@@ -237,6 +250,32 @@ class SubscriberWindows(object):
         self.update_frames()
         msg_cmd = sub_cmd.get()
         key = self.handle_keys(cv2.waitKey(1))
+        if self.sock_list:
+            for s, t in zip(self.sock_list, self.top_list):
+                f = list(self.frames.values())
+                if f:
+                    s.send_multipart([t] + [encode_buffer(fr) for fr in f])
+        return msg_cmd, key
+
+    def _update_multiple(self, arr: Union[List[np.ndarray], np.ndarray] = None, id: Union[List[str], List[int]] = None):
+        if arr is not None and id is not None:
+            for arr_i, id_i in zip(arr, id):
+                global_cv_display_callback(arr_i, id_i)  # type: ignore
+                if id_i not in self.input_cams:
+                    self.add_source(id_i)
+                    if not self.silent:
+                        self.add_window(id_i)
+
+        sub_cmd = window_commands.win_cmd_sub()
+        self.update_frames()
+        msg_cmd = sub_cmd.get()
+        key = self.handle_keys(cv2.waitKey(1))
+        if self.sock_list:
+            for s, t in zip(self.sock_list, self.top_list):
+                f = list(self.frames.values())
+                if f:
+                    s.send_multipart([t] + [encode_buffer(fr) for fr in f])
+
         return msg_cmd, key
 
     def wait_for_init(self):
@@ -277,6 +316,14 @@ class SubscriberWindows(object):
         window_commands.quit(force_all_read=False)
         self.__stop_all_cams()
 
+    def publish_to(self, address, topic=b""):
+        """Publish the current video to the specified address and topic over a zmq publisher."""
+        if self.ctx==None:
+            self.ctx = zmq.Context()
+        self.sock_list.append(self.ctx.socket(zmq.PUB))
+        self.sock_list[-1].bind(address)
+        self.top_list.append(topic)
+
     @property
     def cams(self):
         """Get the camera instances. Can be used for OpenCV or V4L2 functions, depending on backend."""
@@ -337,6 +384,7 @@ def _get_video_threads(
     fps=float("inf"),
     size=(-1, -1),
     force_backend="",
+    mjpg=True
 ):
     vid_threads: List[Thread] = []
     if isinstance(callbacks, Dict):
@@ -352,6 +400,7 @@ def _get_video_threads(
                     fps_limit=fps,
                     request_size=size,
                     force_backend=force_backend,
+                    mjpg=mjpg
                 )
             )
     elif callable(callbacks):
@@ -363,6 +412,7 @@ def _get_video_threads(
                     fps_limit=fps,
                     request_size=size,
                     force_backend=force_backend,
+                    mjpg=mjpg
                 )
             )
     else:
@@ -370,7 +420,7 @@ def _get_video_threads(
             if v is not None:
                 vid_threads.append(
                     FrameUpdater(
-                        v, fps_limit=fps, request_size=size, force_backend=force_backend
+                        v, fps_limit=fps, request_size=size, force_backend=force_backend, mjpg=mjpg
                     )
                 )
     return vid_threads
@@ -391,6 +441,7 @@ def display(
     size=(-1, -1),
     silent=False,
     force_backend="",
+    mjpg=True
 ):
     """
     Display all the arrays, cameras, and videos passed in.
@@ -405,6 +456,7 @@ def display(
         fps=fps_limit,
         size=size,
         force_backend=force_backend,
+        mjpg=mjpg
     )
     for v in vid_threads:
         v.start()
@@ -432,3 +484,21 @@ def breakpoint_display(*args, **kwargs):
 def read_updates(*args, **kwargs):
     """Read back all frame updates and yield a list of frames. List is empty if no frames were read."""
     return display(*args, **kwargs, silent=True)
+
+
+def publish_updates(*args, address="tcp://127.0.0.1:7880", topic=b"", **kwargs):
+    """Publish all the updates to the given address and topic."""
+    if 'blocking' in kwargs and kwargs['blocking']:
+        block = True
+        kwargs['blocking'] = False
+    else:
+        block = False
+
+    r = read_updates(*args, **kwargs)
+    r.publish_to(address, topic)
+
+    if block:
+        r.loop()
+        for vt in r.close_threads:
+            vt.join()
+    return r
